@@ -1,5 +1,6 @@
 import functools
 import inspect
+import time
 import json
 from typing import Callable, Union, Dict
 
@@ -66,6 +67,7 @@ def check_access_rights(service: str,
 
         @functools.wraps(job_func)
         def wrapper(*args, **kwargs):
+            start = time.time()
             is_appengine_cron = request.headers.get('X-Appengine-Cron', False)
 
             if is_appengine_cron:
@@ -73,6 +75,7 @@ def check_access_rights(service: str,
                 return job_func(*args, **kwargs)
 
             claims = {}
+            origin = ''
             # Check feature rights
             if auth_enabled:
                 token = str(request.headers.get('Authorization', '')).split(' ').pop()
@@ -87,14 +90,6 @@ def check_access_rights(service: str,
                 except ValueError as e:
                     return {'detail': str(e)}, 401
 
-                try:
-                    send_tracking_information(email=claims['email'], service=service, function_name=job_func.__name__, origin=origin,
-                                            project=project, pubsub_client=pubsub_client, datastore_client=datastore_client)
-                except (KeyError, ServiceUnavailable):
-                    # Failing to send tracking info should not impact feature usability
-                    pass
-
-
                 try:
                     _check_feature_right_access(
                         claims,
@@ -136,8 +131,25 @@ def check_access_rights(service: str,
                     authorized_clients = [client_entity.key.name for client_entity in clients_query.fetch()]
 
                 kwargs[CLIENTS_PARAM] = sorted(set(authorized_clients))
+            executable = job_func(*args, **kwargs)
+            end = time.time()
 
-            return job_func(*args, **kwargs)
+            if auth_enabled:
+                try:
+                    send_tracking_information(
+                        email=claims['email'],
+                        service=service,
+                        function_name=job_func.__name__,
+                        origin=origin,
+                        project=project,
+                        execution_time=end - start,
+                        pubsub_client=pubsub_client,
+                        datastore_client=datastore_client)
+                except (KeyError, ServiceUnavailable):
+                    # Failing to send tracking info should not impact feature usability
+                    pass
+
+            return executable
 
         return wrapper
     return check_rights
