@@ -11,8 +11,15 @@ from arcane.pubsub import Client as PubSubClient
 PUBSUB_ACTIVITY_TRACKING_TOPIC = 'activity-tracker'
 
 
-def send_tracking_information(email: str, service: str, function_name: str, origin: str, project: str,
-                              pubsub_client: PubSubClient, datastore_client: DatastoreClient) -> None:
+def send_tracking_information(
+    email: str,
+    service: str,
+    function_name: str,
+    origin: str,
+    project: str,
+    execution_time: float,
+    pubsub_client: PubSubClient,
+    datastore_client: DatastoreClient) -> None:
     """ Send pubsub message to the tracking cloud function"""
 
     users_query = datastore_client.query(kind='users')
@@ -28,6 +35,7 @@ def send_tracking_information(email: str, service: str, function_name: str, orig
             topic_name=PUBSUB_ACTIVITY_TRACKING_TOPIC,
             parameters={'user_email': email,
              'service': service,
+             'execution_time': execution_time,
              'timestamp': timestamp,
              'function_name': function_name,
              'insert_id': insert_id,
